@@ -54,7 +54,7 @@ def async_wrap(func):
 
 def get_event_loop():
     try:
-        loop = asyncio.get_event_loop()
+        loop = asyncio.get_running_loop()
     except RuntimeError:
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
@@ -67,7 +67,7 @@ def get_event_loop():
 
 def run_coroutine(coro):
     loop = get_event_loop()
-    aws = asyncio.ensure_future(coro)
+    aws = asyncio.ensure_future(coro, loop=loop)
     result = loop.run_until_complete(aws)
     return result
 
