@@ -12,7 +12,12 @@ from cve_bin_tool.checkers import Checker
 
 
 class AvahiChecker(Checker):
-    CONTAINS_PATTERNS = []
+    CONTAINS_PATTERNS = [
+        r"avahi_free",
+        r"avahi_strerror",
+        # r"avahi_string_list_free",
+        # r"libavahi-common.so.3",
+    ]
     FILENAME_PATTERNS = [r"avahi-daemon"]
     VERSION_PATTERNS = [r"avahi ([0-9]+\.[0-9]+\.[0-9]+)"]
     VENDOR_PRODUCT = [("avahi", "avahi")]
