@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for gimp
@@ -6,7 +8,7 @@ CVE checker for gimp
 https://www.cvedetails.com/product/17152/Gimp-Gimp.html?vendor_id=9605
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class GimpChecker(Checker):
