@@ -1,10 +1,12 @@
-#!/usr/bin/env python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE checker for GnuTLS
 References:
 https://www.cvedetails.com/vulnerability-list/vendor_id-72/product_id-4433/GNU-Gnutls.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class GnutlsChecker(Checker):
