@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libarchive
@@ -6,7 +8,7 @@ CVE checker for libarchive
 https://www.cvedetails.com/product/26168/Libarchive-Libarchive.html?vendor_id=12872
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibarchiveChecker(Checker):
