@@ -13,10 +13,9 @@ from cve_bin_tool.checkers import Checker
 
 class LibsndfileChecker(Checker):
     CONTAINS_PATTERNS = [
-        r"This version of libsndfile was compiled without Ogg/Speex support.",
         r"No error defined for this error number. This is a bug in libsndfile.",
         r"NULL SF_INFO pointer passed to libsndfile.",
-        r"MATLAB 5.0 MAT-file, written by libsndfile-\d+\.\d+\.\d+,",
+        # r"MATLAB 5.0 MAT-file, written by libsndfile-(\d+\.\d+\.\d+),",
     ]
     FILENAME_PATTERNS = [r"libsndfile.so"]
     VERSION_PATTERNS = [r"libsndfile-(\d+\.\d+\.\d+)"]
