@@ -11,7 +11,10 @@ from cve_bin_tool.checkers import Checker
 
 
 class Libssh2Checker(Checker):
-    CONTAINS_PATTERNS = []
+    CONTAINS_PATTERNS = [
+        r"Invalid descriptor passed to libssh2_poll()",
+        r"libssh2_channel_wait_closed() invoked when channel is not in EOF state",
+    ]
     FILENAME_PATTERNS = [r"libssh2"]
     VERSION_PATTERNS = [r"SSH-2.0-libssh2_([0-9]+\.[0-9]+\.[0-9]+)"]
     VENDOR_PRODUCT = [("libssh2", "libssh2")]
