@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for memcached
@@ -6,7 +8,7 @@ CVE checker for memcached
 https://www.cvedetails.com/product/26610/Memcached-Memcached.html?vendor_id=12993
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class MemcachedChecker(Checker):
