@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for openafs
@@ -6,7 +8,7 @@ CVE checker for openafs
 https://www.cvedetails.com/product/2873/Openafs-Openafs.html?vendor_id=1664
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class OpenafsChecker(Checker):
