@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for postgresql
@@ -6,7 +8,7 @@ CVE checker for postgresql
 https://www.cvedetails.com/product/575/Postgresql-Postgresql.html?vendor_id=336
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class PostgresqlChecker(Checker):
