@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for qt
@@ -7,7 +9,7 @@ https://www.cvedetails.com/product/10758/QT-QT.html?vendor_id=6363
 https://www.cvedetails.com/product/24410/Digia-QT.html?vendor_id=12593
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class QtChecker(Checker):
