@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for radare2
@@ -6,7 +8,7 @@ CVE checker for radare2
 https://www.cvedetails.com/product/36037/Radare-Radare2.html?vendor_id=16137
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class Radare2Checker(Checker):
