@@ -1,10 +1,12 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for rsyslog
 https://www.cvedetails.com/product/15708/Rsyslog-Rsyslog.html?vendor_id=3361
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class RsyslogChecker(Checker):
