@@ -12,8 +12,8 @@ CVE list: https://www.cvedetails.com/vulnerability-list/vendor_id-9237/product_i
 
 """
 import re
-import urllib.error as error
-import urllib.request as request
+
+import requests
 
 from cve_bin_tool.checkers import Checker
 from cve_bin_tool.log import LOGGER
@@ -31,13 +31,11 @@ def get_version_map():
         re.compile(r'"*(\d{4}-\d{2}-\d{2} \d+:\d+:\d+ [\w]+)"*'),
     ]
     try:
-        response = request.urlopen(changeurl)  # nosec - static url above
-        lines = response.readlines()
+        response = requests.get(changeurl).text
+        lines = response.splitlines()
 
         last_version = "UNKNOWN"
-        for line_encoded in lines:
-            line = line_encoded.decode("UTF-8")
-
+        for line in lines:
             ver_match = version_pattern.search(line)
             if ver_match:
                 last_version = ver_match.group(1)
@@ -47,7 +45,7 @@ def get_version_map():
                     version_map.append([last_version, id_match.group(1)])
                     break
 
-    except error.URLError as err:
+    except requests.RequestException as err:
         LOGGER.error("Could not fetch " + changeurl + ", " + str(err))
 
     return version_map
