@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for strongswan
@@ -6,7 +8,7 @@ CVE checker for strongswan
 https://www.cvedetails.com/product/3992/Strongswan-Strongswan.html?vendor_id=2278
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class StrongswanChecker(Checker):
