@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for subversion CLI
@@ -6,7 +8,7 @@ References:
 https://subversion.apache.org/
 https://www.cvedetails.com/vulnerability-list/vendor_id-2120/product_id-3608/Subversion-Subversion.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class SubversionChecker(Checker):
