@@ -60,7 +60,8 @@ class Xml2Checker(Checker):
                 new_guess2 = match.group(1).strip()
                 if len(new_guess2) > len(new_guess):
                     new_guess = new_guess2
-        return new_guess
+        # If no version guessed, set version to "UNKNOWN"
+        return new_guess or "UNKNOWN"
 
     def get_version(self, lines, filename):
         version_info = super().get_version(lines, filename)
