@@ -2,6 +2,14 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 
+# This file is not meant to be run directly.
+# It should be properly installed so the checkers will load correctly.
+# Refer to:
+#       manual (https://cve-bin-tool.readthedocs.io/en/latest/MANUAL.html)
+#       on how to use the tool, or
+#       installation guide (https://cve-bin-tool.readthedocs.io/en/latest/README.html#installing-cve-binary-tool)
+#       on how to install the tool.
+
 """
 This tool scans for a number of common, vulnerable open source components
 (openssl, libpng, libxml2, expat and a few others) to let you know if your
@@ -13,16 +21,16 @@ of those published lists.
 """
 
 import argparse
+import importlib.util
 import logging
 import os
 import platform
 import sys
 import textwrap
+import time
 from collections import ChainMap
 from typing import Dict
 
-import pkg_resources
-
 from cve_bin_tool.available_fix import (
     AvailableFixReport,
     get_available_fix_supported_distros,
@@ -49,6 +57,11 @@ from cve_bin_tool.util import ProductInfo
 from cve_bin_tool.version import VERSION
 from cve_bin_tool.version_scanner import VersionScanner
 
+if sys.version_info >= (3, 8):
+    from importlib import metadata as importlib_metadata
+else:
+    import importlib_metadata
+
 sys.excepthook = excepthook  # Always install excepthook for entrypoint module.
 
 
@@ -91,6 +104,7 @@ def main(argv=None):
         action="store",
         choices=["api", "json"],
         help="choose method for getting CVE lists from NVD",
+        default="api",
     )
     nvd_database_group.add_argument(
         "-u",
@@ -98,11 +112,18 @@ def main(argv=None):
         action="store",
         choices=["now", "daily", "never", "latest"],
         help="update schedule for NVD database (default: daily)",
+        default="daily",
+    )
+    nvd_database_group.add_argument(
+        "--nvd-api-key",
+        action="store",
+        default="",
+        help="specify NVD API key (used to improve NVD rate limit)",
     )
 
     input_group = parser.add_argument_group("Input")
     input_group.add_argument(
-        "directory", help="directory to scan", nargs="?", default=None
+        "directory", help="directory to scan", nargs="?", default=""
     )
     input_group.add_argument(
         "-i",
@@ -128,11 +149,16 @@ def main(argv=None):
         "--sbom-file",
         action="store",
         help="provide sbom filename",
+        default="",
     )
 
     output_group = parser.add_argument_group("Output")
     output_group.add_argument(
-        "-q", "--quiet", action="store_true", help="suppress output"
+        "-q",
+        "--quiet",
+        action="store_true",
+        help="suppress output",
+        default=False,
     )
     output_group.add_argument(
         "-l",
@@ -141,17 +167,20 @@ def main(argv=None):
         dest="log_level",
         action="store",
         choices=["debug", "info", "warning", "error", "critical"],
+        default="info",
     )
     output_group.add_argument(
         "-o",
         "--output-file",
         action="store",
         help="provide output filename (default: output to stdout)",
+        default="",
     )
     output_group.add_argument(
         "--html-theme",
         action="store",
         help="provide custom theme directory for HTML Report",
+        default="",
     )
     output_group.add_argument(
         "-f",
@@ -159,12 +188,14 @@ def main(argv=None):
         action="store",
         choices=["csv", "json", "console", "html", "pdf"],
         help="update output format (default: console)",
+        default="console",
     )
     output_group.add_argument(
         "-c",
         "--cvss",
         action="store",
         help="minimum CVSS score (as integer in range 0 to 10) to report (default: 0)",
+        default=0,
     )
     output_group.add_argument(
         "-S",
@@ -172,11 +203,13 @@ def main(argv=None):
         action="store",
         choices=["low", "medium", "high", "critical"],
         help="minimum CVE severity to report (default: low)",
+        default="low",
     )
     output_group.add_argument(
         "--report",
         action="store_true",
         help="Produces a report even if there are no CVE for the respective output format",
+        default=False,
     )
     output_group.add_argument(
         "-A",
@@ -187,6 +220,7 @@ def main(argv=None):
         choices=get_available_fix_supported_distros(),
         metavar="<distro_name>-<distro_version_name>",
         help="Lists available fixes of the package from Linux distribution",
+        default="",
     )
     output_group.add_argument(
         "-b",
@@ -197,6 +231,7 @@ def main(argv=None):
         choices=get_backport_supported_distros(),
         metavar="<distro_name>-<distro_version_name>",
         help="Lists backported fixes if available from Linux distribution",
+        default="",
     )
     output_group.add_argument(
         "--affected-versions",
@@ -205,18 +240,37 @@ def main(argv=None):
         help="Lists versions of product affected by a given CVE (to facilitate upgrades)",
     )
 
+    output_group.add_argument(
+        "--vex",
+        action="store",
+        help="Provide vulnerability exchange (vex) filename",
+        default="",
+    )
+
     parser.add_argument(
         "-e",
         "--exclude",
         action=StringToListAction,
         help="Comma separated Exclude directory path",
-        default=None,
+        default=[],
     )
     parser.add_argument("-V", "--version", action="version", version=VERSION)
     parser.add_argument(
         "--disable-version-check",
         action="store_true",
         help="skips checking for a new version",
+        default=False,
+    )
+    parser.add_argument(
+        "--disable-validation-check",
+        action="store_true",
+        help="skips checking xml files against schema",
+    )
+    parser.add_argument(
+        "--offline",
+        action="store_true",
+        help="operate in offline mode",
+        default=False,
     )
 
     merge_report_group = parser.add_argument_group(
@@ -228,24 +282,28 @@ def main(argv=None):
         nargs="?",
         const=True,
         help="save output as intermediate report in json format",
+        default=False,
     )
     merge_report_group.add_argument(
         "-t",
         "--tag",
         action="store",
         help="add a unique tag to differentiate between multiple intermediate reports",
+        default="",
     )
     merge_report_group.add_argument(
         "-m",
         "--merge",
         action=StringToListAction,
         help="comma separated intermediate reports path for merging",
+        default=None,
     )
     merge_report_group.add_argument(
         "-F",
         "--filter",
         action=StringToListAction,
         help="comma separated tag string for filtering intermediate reports",
+        default=[],
     )
 
     checker_group = parser.add_argument_group("Checkers")
@@ -256,6 +314,7 @@ def main(argv=None):
         action=StringToListAction,
         type=str,
         help="comma-separated list of checkers to disable",
+        default="",
     )
     checker_group.add_argument(
         "-r",
@@ -264,6 +323,7 @@ def main(argv=None):
         action=StringToListAction,
         type=str,
         help="comma-separated list of checkers to enable",
+        default="",
     )
 
     deprecated_group = parser.add_argument_group("Deprecated")
@@ -272,41 +332,13 @@ def main(argv=None):
         "--extract",
         action="store_true",
         help="autoextract compressed files",
+        default=True,
     )
 
-    defaults = {
-        "directory": "",
-        "exclude": [],
-        "input_file": "",
-        "log_level": "info",
-        "format": "console",
-        "cvss": 0,
-        "severity": "low",
-        "update": "daily",
-        "extract": True,
-        "disable_version_check": False,
-        "skips": "",
-        "runs": "",
-        "quiet": False,
-        "output_file": "",
-        "html_theme": "",
-        "report": False,
-        "package_list": "",
-        "append": False,
-        "tag": "",
-        "merge": None,
-        "backport_fix": "",
-        "available_fix": "",
-        "nvd": "api",
-        "filter": [],
-        "affected_versions": 0,
-        "sbom": "spdx",
-        "sbom_file": "",
-    }
-
     with ErrorHandler(mode=ErrorMode.NoTrace):
         raw_args = parser.parse_args(argv[1:])
         args = {key: value for key, value in vars(raw_args).items() if value}
+        defaults = {key: parser.get_default(key) for key in vars(raw_args)}
 
     configs = {}
     if args.get("config"):
@@ -329,6 +361,27 @@ def main(argv=None):
     else:
         error_mode = ErrorMode.TruncTrace
 
+    # once logging is set, we can output the version and NVD notice
+    LOGGER.info(f"CVE Binary Tool v{VERSION}")
+    LOGGER.info(
+        "This product uses the NVD API but is not endorsed or certified by the NVD."
+    )
+
+    # If NVD API key is not set, check for environment variable (e.g. GitHub Secrets)
+    if not args["nvd_api_key"] and os.getenv("nvd_api_key"):
+        args["nvd_api_key"] = os.getenv("nvd_api_key")
+
+    # Also try the uppercase env variable, in case people prefer those
+    if not args["nvd_api_key"] and os.getenv("NVD_API_KEY"):
+        args["nvd_api_key"] = os.getenv("NVD_API_KEY")
+
+    # If you're not using an NVD key, let you know how to get one
+    if not args["nvd_api_key"] and not args["offline"]:
+        LOGGER.info("Not using an NVD API key. Your access may be rate limited by NVD.")
+        LOGGER.info(
+            "Get an NVD API key here: https://nvd.nist.gov/developers/request-an-api-key"
+        )
+
     if platform.system() != "Linux":
         warning_nolinux = """
                           **********************************************
@@ -348,6 +401,24 @@ def main(argv=None):
     if int(args["cvss"]) > 0:
         score = int(args["cvss"])
 
+    # Offline processing
+    if args["offline"]:
+        # Override version check and database update arguments
+        version_check = True
+        db_update = "never"
+    else:
+        version_check = args["disable_version_check"]
+        db_update = args["update"]
+
+    # Check for PDF support
+    output_format = args["format"]
+    if output_format == "pdf" and importlib.util.find_spec("reportlab") is None:
+        LOGGER.info("PDF output not available. Default to console.")
+        LOGGER.info(
+            "If you want to produce PDF output, please install reportlab using pip install reportlab"
+        )
+        output_format = "console"
+
     merged_reports = None
     if args["merge"]:
         LOGGER.info(
@@ -370,12 +441,11 @@ def main(argv=None):
     # Database update related settings
     # Connect to the database
     cvedb_orig = CVEDB(
-        version_check=not args["disable_version_check"],
+        version_check=not version_check,
         error_mode=error_mode,
         nvd_type=args["nvd"],
-        incremental_update=True
-        if args["update"] == "latest" and args["nvd"]
-        else False,
+        incremental_update=True if db_update == "latest" and args["nvd"] else False,
+        nvd_api_key=args["nvd_api_key"],
     )
 
     # if OLD_CACHE_DIR (from cvedb.py) exists, print warning
@@ -384,15 +454,23 @@ def main(argv=None):
             f"Obsolete cache dir {OLD_CACHE_DIR} is no longer needed and can be removed."
         )
 
+    # Check database exists if operating in offline mode.
+    if args["offline"] and not cvedb_orig.check_db_exists():
+        LOGGER.critical("Database does not exist.")
+        LOGGER.info(
+            "Consult the documentation at https://cve-bin-tool.readthedocs.io/en/latest/how_to_guides/offline.html to find out how to setup offline operation."
+        )
+        return -1
+
     # Clear data if -u now is set
-    if args["update"] == "now":
+    if db_update == "now":
         cvedb_orig.clear_cached_data()
 
-    if args["update"] == "latest":
+    if db_update == "latest":
         cvedb_orig.refresh_cache_and_update_db()
 
     # update db if needed
-    if args["update"] != "never":
+    if db_update != "never":
         cvedb_orig.get_cvelist_if_stale()
     else:
         if args["nvd"] == "json":
@@ -407,6 +485,12 @@ def main(argv=None):
         with ErrorHandler(mode=error_mode, logger=LOGGER):
             raise CVEDataMissing("No data in CVE Database")
 
+    # Report time of last database update
+    db_date = time.strftime(
+        "%d %B %Y at %H:%M:%S", time.localtime(cvedb_orig.get_db_update_date())
+    )
+    LOGGER.info(f"CVE database last updated on {db_date}")
+
     cvedb_orig.remove_cache_backup()
 
     # Input validation
@@ -443,7 +527,7 @@ def main(argv=None):
                 lambda checker: checker.name,
                 filter(
                     lambda checker: checker.name not in runs,
-                    pkg_resources.iter_entry_points("cve_bin_tool.checker"),
+                    importlib_metadata.entry_points()["cve_bin_tool.checker"],
                 ),
             )
         )
@@ -477,6 +561,7 @@ def main(argv=None):
                 should_extract=args["extract"],
                 exclude_folders=args["exclude"],
                 error_mode=error_mode,
+                validate=not args["disable_validation_check"],
             )
             version_scanner.remove_skiplist(skips)
             LOGGER.info(f"Number of checkers: {version_scanner.number_of_checkers()}")
@@ -497,7 +582,10 @@ def main(argv=None):
         if args["sbom_file"]:
             # Process SBOM file
             sbom_list = SBOMManager(
-                args["sbom_file"], sbom_type=args["sbom"], logger=LOGGER
+                args["sbom_file"],
+                sbom_type=args["sbom"],
+                logger=LOGGER,
+                validate=not args["disable_validation_check"],
             )
             parsed_data = sbom_list.scan_file()
             LOGGER.info(
@@ -542,10 +630,11 @@ def main(argv=None):
                 append=args["append"],
                 merge_report=merged_reports,
                 affected_versions=args["affected_versions"],
+                vex_filename=args["vex"],
             )
 
             if not args["quiet"]:
-                output.output_file(args["format"])
+                output.output_file(output_format)
                 if args["backport_fix"] or args["available_fix"]:
                     distro_info = args["backport_fix"] or args["available_fix"]
                     is_backport = True if args["backport_fix"] else False
