@@ -32,7 +32,7 @@ from cve_bin_tool.error_handler import (
 )
 from cve_bin_tool.log import LOGGER
 from cve_bin_tool.nvd_api import NVD_API
-from cve_bin_tool.version import VERSION, check_latest_version
+from cve_bin_tool.version import check_latest_version
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -71,6 +71,7 @@ class CVEDB:
         error_mode=ErrorMode.TruncTrace,
         nvd_type="json",
         incremental_update=False,
+        nvd_api_key: str = "",
     ):
         self.feed = feed if feed is not None else self.FEED
         self.cachedir = cachedir if cachedir is not None else self.CACHEDIR
@@ -93,6 +94,9 @@ class CVEDB:
         self.incremental_update = incremental_update
         self.all_cve_entries = None
 
+        # store the nvd api key for use later
+        self.nvd_api_key = nvd_api_key
+
         if not os.path.exists(self.dbpath):
             self.rollback_cache_backup()
 
@@ -108,6 +112,7 @@ class CVEDB:
             logger=self.LOGGER,
             error_mode=self.error_mode,
             incremental_update=self.incremental_update,
+            api_key=self.nvd_api_key,
         )
         if self.incremental_update:
             await nvd_api.get_nvd_params(
@@ -122,6 +127,9 @@ class CVEDB:
         nvd_api.session = None
         return nvd_api.all_cve_entries
 
+    def check_db_exists(self):
+        return os.path.isfile(self.dbpath)
+
     def get_db_update_date(self):
         # last time when CVE data was updated
         self.time_of_last_update = datetime.datetime.fromtimestamp(
@@ -253,7 +261,7 @@ class CVEDB:
         # refresh the database
         if not os.path.isdir(self.cachedir):
             os.makedirs(self.cachedir)
-        self.LOGGER.info(f"CVE Binary Tool v{VERSION}")
+
         # check for the latest version
         if self.version_check:
             check_latest_version()
