@@ -1,12 +1,23 @@
 # Copyright (C) 2021 Intel Corporation
 # SPDX-License-Identifier: GPL-3.0-or-later
 
+import ast
 import os
 import sys
 from io import StringIO
 
+from setuptools import find_packages
 from setuptools.dist import Distribution
 
+try:
+    from cve_bin_tools.version import VERSION
+except ModuleNotFoundError:
+    with open(os.path.join("cve_bin_tool", "version.py")) as f:
+        for line in f:
+            if line.startswith("VERSION"):
+                VERSION = ast.literal_eval(line.strip().split("=")[-1].strip())
+                break
+
 
 def IS_DEVELOP() -> bool:
     return any(
@@ -35,7 +46,15 @@ def update_egg() -> None:
                 script_name="setup.py",
                 script_args=["egg_info"],
                 name="cve-bin-tool",
+                version=VERSION,
+                packages=find_packages(
+                    exclude=["locales", "presentation"],
+                ),
                 entry_points={
+                    "console_scripts": [
+                        "cve-bin-tool = cve_bin_tool.cli:main",
+                        "csv2cve = cve_bin_tool.csv2cve:main",
+                    ],
                     "cve_bin_tool.checker": [
                         "{} = cve_bin_tool.checkers.{}:{}".format(
                             filename.replace(".py", ""),
