@@ -3,6 +3,7 @@
 
 from datetime import datetime
 
+from reportlab import rl_config
 from reportlab.graphics.shapes import Drawing, Rect, String
 from reportlab.lib import colors
 from reportlab.lib.styles import ParagraphStyle as PS
@@ -169,6 +170,9 @@ class PDFBuilder:
         self.table_data = []
         self.note_data = []
         self.table_validation = None
+        # Set default configuration parameters
+        rl_config.trustedHosts = ["localhost", "127.0.0.1"]
+        rl_config.trustedSchemes = ["http", "https"]
 
     def _spacer(self):
         self.contents.append(self.spacer)
