@@ -7,22 +7,24 @@ the tool is able to support other operating systems like Windows
 and MacOS.
 """
 
+from typing import ClassVar, List, Set
+
 from cve_bin_tool.async_utils import FileIO, run_coroutine
 
 
 class Strings:
     # printable characters
-    PRINTABLE = set(range(32, 128))
+    PRINTABLE: ClassVar[Set[int]] = set(range(32, 128))
     # add tab to the printable character
     PRINTABLE.add(9)
 
-    def __init__(self, filename=""):
+    def __init__(self, filename: str = "") -> None:
         self.filename = filename
-        self.output = ""
+        self.output: str = ""
 
-    async def aio_parse(self):
+    async def aio_parse(self) -> str:
         async with FileIO(self.filename, "rb") as f:
-            tmp = []
+            tmp: List[str] = []
             async for line in f:
                 for char in line:
                     # remove all unprintable characters
@@ -33,5 +35,5 @@ class Strings:
                         tmp = []
         return self.output
 
-    def parse(self):
+    def parse(self) -> str:
         return run_coroutine(self.aio_parse())
