@@ -2,31 +2,32 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 """ Utility classes for the CVE Binary Tool """
+from __future__ import annotations
+
 import fnmatch
 import os
 import sys
-from collections import defaultdict
 from enum import Enum
-from typing import NamedTuple
+from typing import DefaultDict, Iterator, List, NamedTuple, Pattern, Set, Union
 
 
 class OrderedEnum(Enum):
-    def __ge__(self, other):
+    def __ge__(self, other: OrderedEnum) -> bool:
         if self.__class__ is other.__class__:
             return self.value >= other.value
         return NotImplemented
 
-    def __gt__(self, other):
+    def __gt__(self, other: OrderedEnum) -> bool:
         if self.__class__ is other.__class__:
             return self.value > other.value
         return NotImplemented
 
-    def __le__(self, other):
+    def __le__(self, other: OrderedEnum) -> bool:
         if self.__class__ is other.__class__:
             return self.value <= other.value
         return NotImplemented
 
-    def __lt__(self, other):
+    def __lt__(self, other: OrderedEnum) -> bool:
         if self.__class__ is other.__class__:
             return self.value < other.value
         return NotImplemented
@@ -39,7 +40,7 @@ class Remarks(OrderedEnum):
     Mitigated = 4, "4", "Mitigated", "m", "M"
     Ignored = 5, "5", "Ignored", "i", "I"
 
-    def __new__(cls, value, *aliases):
+    def __new__(cls, value: int, *aliases: str) -> Remarks:
         obj = object.__new__(cls)
         obj._value_ = value
         for alias in aliases:
@@ -64,6 +65,11 @@ class ProductInfo(NamedTuple):
     version: str
 
 
+class ScanInfo(NamedTuple):
+    product_info: ProductInfo
+    file_path: str
+
+
 class VersionInfo(NamedTuple):
     start_including: str
     start_excluding: str
@@ -71,18 +77,20 @@ class VersionInfo(NamedTuple):
     end_excluding: str
 
 
-class CVEData(defaultdict):
-    def __missing__(self, key):
+class CVEData(DefaultDict[str, Union[List[CVE], Set[str]]]):
+    def __missing__(self, key: str) -> list[CVE] | set[str]:
         if key == "cves":
-            self[key] = []
+            new_list: list[CVE] = []
+            self[key] = new_list
         elif key == "paths":
-            self[key] = set()
+            new_set: set[str] = set()
+            self[key] = new_set
         else:
             return NotImplemented
         return self[key]
 
 
-def regex_find(lines, version_patterns) -> str:
+def regex_find(lines: str, version_patterns: list[Pattern[str]]) -> str:
     """Search a set of lines to find a match for the given regex"""
     new_guess = ""
 
@@ -98,7 +106,7 @@ def regex_find(lines, version_patterns) -> str:
         return "UNKNOWN"
 
 
-def inpath(binary) -> bool:
+def inpath(binary: str) -> bool:
     """Check to see if something is available in the path.
     Used to check if dependencies are installed before use."""
     if sys.platform == "win32":
@@ -147,7 +155,7 @@ class DirWalk:
         self.yield_files = yield_files
         self.yield_folders = yield_folders
 
-    def walk(self, roots=None):
+    def walk(self, roots: list[str] | None = None) -> Iterator[str]:
         """Walk the directory looking for files matching the pattern"""
         if roots is None:
             roots = []
