@@ -1,15 +1,14 @@
 # Copyright (C) 2021 Intel Corporation
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import json
 import textwrap
-from urllib import request
 
+import requests
 from packaging import version
 
 from cve_bin_tool.log import LOGGER
 
-VERSION: str = "3.0"
+VERSION: str = "3.1"
 
 
 def check_latest_version():
@@ -18,19 +17,18 @@ def check_latest_version():
     name: str = "cve-bin-tool"
     url: str = f"https://pypi.org/pypi/{name}/json"
     try:
-        with request.urlopen(url) as resp:  # nosec - static url above
-            package_json = json.load(resp)
-            pypi_version = package_json["info"]["version"]
-            if pypi_version != VERSION:
+        package_json = requests.get(url).json()
+        pypi_version = package_json["info"]["version"]
+        if pypi_version != VERSION:
+            LOGGER.info(
+                f"[bold red]You are running version {VERSION} of {name} but the latest PyPI Version is {pypi_version}.[/]",
+                extra={"markup": True},
+            )
+            if version.parse(VERSION) < version.parse(pypi_version):
                 LOGGER.info(
-                    f"[bold red]You are running version {VERSION} of {name} but the latest PyPI Version is {pypi_version}.[/]",
+                    "[bold yellow]Alert: We recommend using the latest stable release.[/]",
                     extra={"markup": True},
                 )
-                if version.parse(VERSION) < version.parse(pypi_version):
-                    LOGGER.info(
-                        "[bold yellow]Alert: We recommend using the latest stable release.[/]",
-                        extra={"markup": True},
-                    )
     except Exception as error:
         LOGGER.warning(
             textwrap.dedent(
