@@ -2,14 +2,19 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 import re
+import sys
 
-import pkg_resources
 import pytest
 
 from cve_bin_tool.checkers import Checker, VendorProductPair
 from cve_bin_tool.egg_updater import IS_DEVELOP, update_egg
 from cve_bin_tool.log import LOGGER
 
+if sys.version_info >= (3, 8):
+    from importlib import metadata as importlib_metadata
+else:
+    import importlib_metadata
+
 Pattern = type(re.compile("", 0))
 
 
@@ -113,7 +118,7 @@ class TestCheckerVersionParser:
     )
     def test_filename_is(self, checker_name, file_name, expected_results):
         """Test a checker's filename detection"""
-        checkers = pkg_resources.iter_entry_points("cve_bin_tool.checker")
+        checkers = importlib_metadata.entry_points()["cve_bin_tool.checker"]
         for checker in checkers:
             if checker.name == checker_name:
                 Checker = checker.load()
@@ -162,7 +167,7 @@ class TestCheckerVersionParser:
             "2.30",
         ]
         file_name = "libc.so.6"
-        checkers = pkg_resources.iter_entry_points("cve_bin_tool.checker")
+        checkers = importlib_metadata.entry_points()["cve_bin_tool.checker"]
         result = None
         for checker in checkers:
             if checker.name == "glibc":
