@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "bash", "version": "1.14.0", "version_strings": ["Bash version 1.14.0"]}
 ]
@@ -9,9 +12,9 @@ package_test_data = [
         "version": "4.0.0",
     },
     {
-        "url": "http://rpmfind.net/linux/mageia/distrib/4/x86_64/media/core/updates/",
-        "package_name": "bash-4.2-53.1.mga4.x86_64.rpm",
+        "url": "http://mirrors.cat.pdx.edu/ubuntu/pool/main/b/bash/",
+        "package_name": "bash_4.4.18-2ubuntu1_amd64.deb",
         "product": "bash",
-        "version": "4.2.53",
+        "version": "4.4.19",
     },
 ]
