@@ -10,5 +10,11 @@ package_test_data = [
         "package_name": "cups-1.3.3-1.fc8.x86_64.rpm",
         "product": "cups",
         "version": "1.3.3",
-    }
+    },
+    {
+        "url": "http://ftp.br.debian.org/debian/pool/main/c/cups/",
+        "package_name": "cups_2.3.3op2-3+deb11u1_amd64.deb",
+        "product": "cups",
+        "version": "2.3.3",
+    },
 ]
