@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "ffmpeg",
@@ -11,8 +14,8 @@ mapping_test_data = [
 package_test_data = [
     {
         "url": "http://archive.ubuntu.com/ubuntu/pool/universe/f/ffmpeg/",
-        "package_name": "ffmpeg_4.1.4-1build2_amd64.deb",
+        "package_name": "ffmpeg_4.3.1-4ubuntu1_amd64.deb",
         "product": "ffmpeg",
-        "version": "4.1.4",
+        "version": "4.3.1",
     }
 ]
