@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "lighttpd",
@@ -7,10 +10,10 @@ mapping_test_data = [
 ]
 package_test_data = [
     {
-        "url": "https://mirrors.kernel.org/fedora/releases/31/Everything/x86_64/os/Packages/l/",
-        "package_name": "lighttpd-1.4.54-2.fc31.x86_64.rpm",
+        "url": "http://mirrors.kernel.org/fedora/releases/33/Everything/x86_64/os/Packages/l/",
+        "package_name": "lighttpd-1.4.55-4.fc33.x86_64.rpm",
         "product": "lighttpd",
-        "version": "1.4.54",
+        "version": "1.4.55",
     },
     {
         "url": "https://ftp.lysator.liu.se/pub/opensuse/distribution/leap/15.1/repo/oss/x86_64/",
