@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "mariadb",
@@ -13,8 +16,8 @@ mapping_test_data = [
 ]
 package_test_data = [
     {
-        "url": "http://security.ubuntu.com/ubuntu/pool/universe/m/mariadb-10.3/",
-        "package_name": "mariadb-client-core-10.3_10.3.22-0ubuntu0.19.10.1_amd64.deb",
+        "url": "http://ports.ubuntu.com/pool/universe/m/mariadb-10.3/",
+        "package_name": "mariadb-client-core-10.3_10.3.22-1ubuntu1_arm64.deb",
         "product": "mariadb",
         "version": "10.3.22",
     }
