@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "memcached", "version": "1.4.1", "version_strings": ["memcached 1.4.1"]}
 ]
@@ -9,9 +12,9 @@ package_test_data = [
         "version": "1.4.0",
     },
     {
-        "url": "https://mirrors.edge.kernel.org/centos/6/os/x86_64/Packages/",
-        "package_name": "memcached-1.4.4-5.el6.x86_64.rpm",
+        "url": "https://mirrors.edge.kernel.org/centos/7/os/x86_64/Packages/",
+        "package_name": "memcached-1.4.15-10.el7_3.1.x86_64.rpm",
         "product": "memcached",
-        "version": "1.4.4",
+        "version": "1.4.15",
     },
 ]
