@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "openswan", "version": "2.6.30", "version_strings": ["Openswan 2.6.30"]}
 ]
@@ -8,10 +11,4 @@ package_test_data = [
         "product": "openswan",
         "version": "2.6.31",
     },
-    {
-        "url": "http://mirror.centos.org/centos/6/os/x86_64/Packages/",
-        "package_name": "openswan-2.6.32-37.el6.x86_64.rpm",
-        "product": "openswan",
-        "version": "2.6.32",
-    },
 ]
