@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "xerces-c",
@@ -8,7 +11,7 @@ mapping_test_data = [
 package_test_data = [
     {
         "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
-        "package_name": "xerces-c-3.1.1-9.el7.x86_64.rpm",
+        "package_name": "xerces-c-3.1.1-10.el7_7.x86_64.rpm",
         "product": "xerces-c",
         "version": "3.1",
     }
