@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "zlib",
@@ -10,8 +13,8 @@ mapping_test_data = [
 ]
 package_test_data = [
     {
-        "url": "http://rpmfind.net/linux/fedora/linux/updates/testing/31/Everything/aarch64/Packages/z/",
-        "package_name": "zlib-1.2.11-19.fc31.aarch64.rpm",
+        "url": "https://kojipkgs.fedoraproject.org/packages/zlib/1.2.11/23.fc33/aarch64/",
+        "package_name": "zlib-1.2.11-23.fc33.aarch64.rpm",
         "product": "zlib",
         "version": "1.2.11",
     },
