@@ -12,9 +12,9 @@ import json
 import os
 import unittest
 from test.utils import LONG_TESTS
-from urllib.request import urlopen
 
 import pytest
+import requests
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
 
@@ -27,7 +27,7 @@ NVD_SCHEMA = "https://scap.nist.gov/schema/nvd/feed/1.1/nvd_cve_feed_json_1.1.sc
 
 class TestJSON:
     # Download the schema
-    SCHEMA = json.loads(urlopen(NVD_SCHEMA).read().decode("utf-8"))
+    SCHEMA = requests.get(NVD_SCHEMA).json()
     LOGGER.info("Schema loaded successfully")
 
     @unittest.skipUnless(LONG_TESTS() > 0, "Skipping long tests")
