@@ -3,6 +3,7 @@
 
 import os
 import re
+from ast import literal_eval
 
 import pytest
 
@@ -80,7 +81,7 @@ class TestMergeReports:
         match = self.MISSING_FIELD_REGEX.search(exc.value.args[0])
         raised_fields = match.group(1)
 
-        assert missing_fields - eval(raised_fields) == set()
+        assert missing_fields - literal_eval(raised_fields) == set()
 
     @pytest.mark.parametrize(
         "filepaths, merged_data",
