@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE-bin-tool util tests
 """
@@ -5,11 +8,11 @@ import inspect
 from typing import DefaultDict
 
 from cve_bin_tool.cve_scanner import CVEScanner
-from cve_bin_tool.util import inpath, CVEData, ProductInfo
+from cve_bin_tool.util import CVEData, ProductInfo, inpath
 
 
 class TestUtil:
-    """ Test the util functions """
+    """Test the util functions"""
 
     def test_inpath(self):
         """Test the check to see if a command line utility is installed
@@ -21,7 +24,7 @@ class TestUtil:
 
 
 class TestSignature:
-    """ Tests signature of critical class and functions"""
+    """Tests signature of critical class and functions"""
 
     def test_cve_scanner(self):
         sig = inspect.signature(CVEScanner.get_cves)
