@@ -7,9 +7,9 @@ Resource definitions and helper utilities for tests.
 import os
 import shutil
 import tempfile
-from urllib.request import urlopen
 
 import pytest
+import requests
 
 from cve_bin_tool.async_utils import get_event_loop
 
@@ -36,9 +36,9 @@ class TempDirTest:
 
 def download_file(url, target):
     """helper method to download a file"""
-    download = urlopen(url)
+    download = requests.get(url)
     with open(target, "wb") as target_file:
-        target_file.write(download.read())
+        target_file.write(download.content)
     download.close()
 
 
